memoize

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2025 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Function

func Function[F func(K) V, K comparable, V any](f F) F

Function memoizes f, caching unique values of k. Initial calls to the resulting function will call f(k), then cache and return v. Subsequent calls will return the cached value for k.

Types

This section is empty.

Jump to